==> lambdaorm-0.8.68.tgz: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

## Versions

### [0.8.68](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.67...v0.8.68) (2023-11-15)

### [0.8.67](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.63...v0.8.67) (2023-11-15)

### [0.8.66](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.65...v0.8.66) (2023-11-15)

### [0.8.65](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.64...v0.8.65) (2023-11-15)

### [0.8.64](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.63...v0.8.64) (2023-11-15)

### [0.8.63](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.62...v0.8.63) (2023-11-15)


### Features

* **syntax:** move syntaxys to .ts files ([ae0d205](https://github.com/FlavioLionelRita/lambdaorm/commit/ae0d205631f4155b4188a43789dac9bc67cbd301)), closes [#189](https://github.com/FlavioLionelRita/lambdaorm/issues/189)

### [0.8.62](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.61...v0.8.62) (2023-11-13)


### Features

* **release:** remove syntax.d.ts to types on package.json and add types on repository/domain/queriable ([6e46e7a](https://github.com/FlavioLionelRita/lambdaorm/commit/6e46e7a1dcfdb82e13c856bac97357910eea5037)), closes [#189](https://github.com/FlavioLionelRita/lambdaorm/issues/189)
* **syntax:** refactorize quereable ([e5a8783](https://github.com/FlavioLionelRita/lambdaorm/commit/e5a878321f26d3d9e82182bbff3c8959c68acbd2)), closes [#189](https://github.com/FlavioLionelRita/lambdaorm/issues/189)

### [0.8.61](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.60...v0.8.61) (2023-11-13)


### Features

* **release:** add syntax.d.ts to types on package.json ([11da720](https://github.com/FlavioLionelRita/lambdaorm/commit/11da72085ff540d5c7d5060ecf58f0d62683e495)), closes [#189](https://github.com/FlavioLionelRita/lambdaorm/issues/189)

### [0.8.60](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.59...v0.8.60) (2023-11-10)


### Bug Fixes

* **security:** update dependences ([f496198](https://github.com/FlavioLionelRita/lambdaorm/commit/f496198b6f9871e6eeaa1142bac51e1031208bf7)), closes [#176](https://github.com/FlavioLionelRita/lambdaorm/issues/176)

### [0.8.59](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.58...v0.8.59) (2023-11-10)

### [0.8.58](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.57...v0.8.58) (2023-11-10)

### [0.8.57](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.56...v0.8.57) (2023-11-10)


### Bug Fixes

* **types:** solve shared types ([d65e38b](https://github.com/FlavioLionelRita/lambdaorm/commit/d65e38bcf43e3958ecbffb447f9b3f86fafaa780)), closes [#179](https://github.com/FlavioLionelRita/lambdaorm/issues/179)

### [0.8.56](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.55...v0.8.56) (2023-11-09)

### [0.8.55](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.54...v0.8.55) (2023-11-09)

### [0.8.54](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.53...v0.8.54) (2023-11-09)

### [0.8.53](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.52...v0.8.53) (2023-11-09)

### Features

* **dependencies:** configure dependabot target to develop ([b66289f](https://github.com/FlavioLionelRita/lambdaorm/commit/b66289f3be82019e6f62065bd9943e680e4a2663)), closes [#176](https://github.com/FlavioLionelRita/lambdaorm/issues/176)

### [0.8.52](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.51...v0.8.52) (2023-11-09)

### Features

* **dependencies:** add dependabot ([45e3c40](https://github.com/FlavioLionelRita/lambdaorm/commit/45e3c40a5f39628b0046b97678563443b1726ff9)), closes [#176](https://github.com/FlavioLionelRita/lambdaorm/issues/176)

### [0.8.51](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.50...v0.8.51) (2023-11-09)

### [0.8.50](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.49...v0.8.50) (2023-11-09)

### Features

* **changelogs:** define header ([c53028a](https://github.com/FlavioLionelRita/lambdaorm/commit/c53028aec123abbf451229284eb02b714b4fd41b)), closes [#176](https://github.com/FlavioLionelRita/lambdaorm/issues/176)

### [0.8.49](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.48...v0.8.49) (2023-11-09)

### [0.8.48](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.47...v0.8.48) (2023-11-09)

### [0.8.47](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.46...v0.8.47) (2023-11-09)

==> lambdaorm-0.8.70.tgz: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

## Versions

### [0.8.70](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.69...v0.8.70) (2023-11-15)

### [0.8.69](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.68...v0.8.69) (2023-11-15)

### [0.8.68](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.67...v0.8.68) (2023-11-15)

### [0.8.67](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.63...v0.8.67) (2023-11-15)

### [0.8.66](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.65...v0.8.66) (2023-11-15)

### [0.8.65](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.64...v0.8.65) (2023-11-15)

### [0.8.64](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.63...v0.8.64) (2023-11-15)

### [0.8.63](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.62...v0.8.63) (2023-11-15)


### Features

* **syntax:** move syntaxys to .ts files ([ae0d205](https://github.com/FlavioLionelRita/lambdaorm/commit/ae0d205631f4155b4188a43789dac9bc67cbd301)), closes [#189](https://github.com/FlavioLionelRita/lambdaorm/issues/189)

### [0.8.62](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.61...v0.8.62) (2023-11-13)


### Features

* **release:** remove syntax.d.ts to types on package.json and add types on repository/domain/queriable ([6e46e7a](https://github.com/FlavioLionelRita/lambdaorm/commit/6e46e7a1dcfdb82e13c856bac97357910eea5037)), closes [#189](https://github.com/FlavioLionelRita/lambdaorm/issues/189)
* **syntax:** refactorize quereable ([e5a8783](https://github.com/FlavioLionelRita/lambdaorm/commit/e5a878321f26d3d9e82182bbff3c8959c68acbd2)), closes [#189](https://github.com/FlavioLionelRita/lambdaorm/issues/189)

### [0.8.61](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.60...v0.8.61) (2023-11-13)


### Features

* **release:** add syntax.d.ts to types on package.json ([11da720](https://github.com/FlavioLionelRita/lambdaorm/commit/11da72085ff540d5c7d5060ecf58f0d62683e495)), closes [#189](https://github.com/FlavioLionelRita/lambdaorm/issues/189)

### [0.8.60](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.59...v0.8.60) (2023-11-10)


### Bug Fixes

* **security:** update dependencies ([f496198](https://github.com/FlavioLionelRita/lambdaorm/commit/f496198b6f9871e6eeaa1142bac51e1031208bf7)), closes [#176](https://github.com/FlavioLionelRita/lambdaorm/issues/176)

### [0.8.59](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.58...v0.8.59) (2023-11-10)

### [0.8.58](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.57...v0.8.58) (2023-11-10)

### [0.8.57](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.56...v0.8.57) (2023-11-10)


### Bug Fixes

* **types:** solve shared types ([d65e38b](https://github.com/FlavioLionelRita/lambdaorm/commit/d65e38bcf43e3958ecbffb447f9b3f86fafaa780)), closes [#179](https://github.com/FlavioLionelRita/lambdaorm/issues/179)

### [0.8.56](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.55...v0.8.56) (2023-11-09)

### [0.8.55](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.54...v0.8.55) (2023-11-09)

### [0.8.54](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.53...v0.8.54) (2023-11-09)

### [0.8.53](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.52...v0.8.53) (2023-11-09)

### Features

* **dependencies:** configure dependabot target to develop ([b66289f](https://github.com/FlavioLionelRita/lambdaorm/commit/b66289f3be82019e6f62065bd9943e680e4a2663)), closes [#176](https://github.com/FlavioLionelRita/lambdaorm/issues/176)

### [0.8.52](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.51...v0.8.52) (2023-11-09)

### Features

* **dependencies:** add dependabot ([45e3c40](https://github.com/FlavioLionelRita/lambdaorm/commit/45e3c40a5f39628b0046b97678563443b1726ff9)), closes [#176](https://github.com/FlavioLionelRita/lambdaorm/issues/176)

### [0.8.51](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.50...v0.8.51) (2023-11-09)

### [0.8.50](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.49...v0.8.50) (2023-11-09)

### Features

* **changelogs:** define header ([c53028a](https://github.com/FlavioLionelRita/lambdaorm/commit/c53028aec123abbf451229284eb02b714b4fd41b)), closes [#176](https://github.com/FlavioLionelRita/lambdaorm/issues/176)

### [0.8.49](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.48...v0.8.49) (2023-11-09)

### [0.8.48](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.47...v0.8.48) (2023-11-09)

### [0.8.47](https://github.com/FlavioLionelRita/lambdaorm/compare/v0.8.46...v0.8.47) (2023-11-09)
